@@ -1,4 +1,4 @@
-use crate::Input;
+use crate::input::Input;
 use std::collections::VecDeque;
 
 pub fn solve(input: &mut Input) -> Result<u32, String> {
